@@ -1,17 +1,33 @@
+from __future__ import annotations
+
 import sys
+from typing import TYPE_CHECKING, Mapping, Optional, Sequence, Union
 
 from graphene import ResolveInfo
 
 import dagster._check as check
 from dagster._config import validate_config_from_snap
+from dagster._core.execution.plan.state import KnownExecutionState
 from dagster._core.host_representation import ExternalPipeline, PipelineSelector, RepositorySelector
-from dagster._core.workspace.context import BaseWorkspaceRequestContext
+from dagster._core.host_representation.external import ExternalExecutionPlan
+from dagster._core.workspace.context import BaseWorkspaceRequestContext, WorkspaceRequestContext
 from dagster._utils.error import serializable_error_info_from_exc_info
 
 from .utils import UserFacingGraphQLError, capture_error
 
+if TYPE_CHECKING:
+    from dagster_graphql.schema.errors import GrapheneRepositoryNotFoundError
+    from dagster_graphql.schema.external import (
+        GrapheneRepository,
+        GrapheneRepositoryConnection,
+        GrapheneWorkspace,
+    )
+    from dagster_graphql.schema.util import HasContext
 
-def get_full_external_job_or_raise(graphene_info, selector):
+
+def get_full_external_job_or_raise(
+    graphene_info: HasContext, selector: PipelineSelector
+) -> ExternalPipeline:
     from ..schema.errors import GraphenePipelineNotFoundError
 
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
@@ -23,10 +39,11 @@ def get_full_external_job_or_raise(graphene_info, selector):
     return graphene_info.context.get_full_external_job(selector)
 
 
-def get_external_pipeline_or_raise(graphene_info, selector):
+def get_external_pipeline_or_raise(
+    graphene_info: HasContext, selector: PipelineSelector
+) -> ExternalPipeline:
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
     check.inst_param(selector, "selector", PipelineSelector)
-
     full_pipeline = get_full_external_job_or_raise(graphene_info, selector)
 
     if selector.solid_selection is None and selector.asset_selection is None:
@@ -35,7 +52,9 @@ def get_external_pipeline_or_raise(graphene_info, selector):
     return get_subset_external_pipeline(graphene_info.context, selector)
 
 
-def get_subset_external_pipeline(context, selector):
+def get_subset_external_pipeline(
+    context: WorkspaceRequestContext, selector: PipelineSelector
+) -> ExternalPipeline:
     from ..schema.errors import GrapheneInvalidSubsetError
     from ..schema.pipelines.pipeline import GraphenePipeline
 
@@ -62,7 +81,9 @@ def get_subset_external_pipeline(context, selector):
     return external_pipeline
 
 
-def ensure_valid_config(external_pipeline, mode, run_config):
+def ensure_valid_config(
+    external_pipeline: ExternalPipeline, mode: Optional[str], run_config: object
+) -> object:
     from ..schema.pipelines.config import GrapheneRunConfigValidationInvalid
 
     check.inst_param(external_pipeline, "external_pipeline", ExternalPipeline)
@@ -71,7 +92,7 @@ def ensure_valid_config(external_pipeline, mode, run_config):
 
     validated_config = validate_config_from_snap(
         config_schema_snapshot=external_pipeline.config_schema_snapshot,
-        config_type_key=external_pipeline.root_config_key_for_mode(mode),
+        config_type_key=check.not_none(external_pipeline.root_config_key_for_mode(mode)),
         config_value=run_config,
     )
 
@@ -87,25 +108,25 @@ def ensure_valid_config(external_pipeline, mode, run_config):
 
 
 def get_external_execution_plan_or_raise(
-    graphene_info,
-    external_pipeline,
-    mode,
-    run_config,
-    step_keys_to_execute,
-    known_state,
-):
+    graphene_info: HasContext,
+    external_pipeline: ExternalPipeline,
+    mode: Optional[str],
+    run_config: Mapping[str, object],
+    step_keys_to_execute: Sequence[str],
+    known_state: KnownExecutionState,
+) -> ExternalExecutionPlan:
 
     return graphene_info.context.get_external_execution_plan(
         external_pipeline=external_pipeline,
         run_config=run_config,
-        mode=mode,
+        mode=check.not_none(mode),
         step_keys_to_execute=step_keys_to_execute,
         known_state=known_state,
     )
 
 
 @capture_error
-def fetch_repositories(graphene_info):
+def fetch_repositories(graphene_info: HasContext) -> GrapheneRepositoryConnection:
     from ..schema.external import GrapheneRepository, GrapheneRepositoryConnection
 
     check.inst_param(graphene_info, "graphene_info", ResolveInfo)
@@ -123,7 +144,9 @@ def fetch_repositories(graphene_info):
 
 
 @capture_error
-def fetch_repository(graphene_info, repository_selector):
+def fetch_repository(
+    graphene_info: HasContext, repository_selector: RepositorySelector
+) -> Union[GrapheneRepository, GrapheneRepositoryNotFoundError]:
     from ..schema.errors import GrapheneRepositoryNotFoundError
     from ..schema.external import GrapheneRepository
 
@@ -145,7 +168,7 @@ def fetch_repository(graphene_info, repository_selector):
 
 
 @capture_error
-def fetch_workspace(workspace_request_context):
+def fetch_workspace(workspace_request_context: WorkspaceRequestContext) -> GrapheneWorkspace:
     from ..schema.external import GrapheneWorkspace, GrapheneWorkspaceLocationEntry
 
     check.inst_param(
