@@ -1,11 +1,12 @@
-from graphql.execution.base import ResolveInfo
+from graphene import ResolveInfo
 
 import dagster._check as check
-from dagster.core.definitions.run_request import InstigatorType
-from dagster.core.host_representation import PipelineSelector, RepositorySelector, SensorSelector
-from dagster.core.scheduler.instigation import InstigatorState, SensorInstigatorData
-from dagster.seven import get_current_datetime_in_utc, get_timestamp_from_utc_datetime
+from dagster._core.definitions.run_request import InstigatorType
+from dagster._core.host_representation import PipelineSelector, RepositorySelector, SensorSelector
+from dagster._core.scheduler.instigation import InstigatorState, SensorInstigatorData
+from dagster._seven import get_current_datetime_in_utc, get_timestamp_from_utc_datetime
 
+from .loader import RepositoryScopedBatchLoader
 from .utils import UserFacingGraphQLError, capture_error
 
 
@@ -18,6 +19,7 @@ def get_sensors_or_error(graphene_info, repository_selector):
 
     location = graphene_info.context.get_repository_location(repository_selector.location_name)
     repository = location.get_repository(repository_selector.repository_name)
+    batch_loader = RepositoryScopedBatchLoader(graphene_info.context.instance, repository)
     sensors = repository.get_external_sensors()
     sensor_states_by_name = {
         state.name: state
@@ -29,10 +31,7 @@ def get_sensors_or_error(graphene_info, repository_selector):
     }
     return GrapheneSensors(
         results=[
-            GrapheneSensor(
-                sensor,
-                sensor_states_by_name.get(sensor.name),
-            )
+            GrapheneSensor(sensor, sensor_states_by_name.get(sensor.name), batch_loader)
             for sensor in sensors
         ]
     )
@@ -94,12 +93,10 @@ def stop_sensor(graphene_info, instigator_origin_id, instigator_selector_id):
         for repository in repository_location.get_repositories().values()
         for sensor in repository.get_external_sensors()
     }
-    instance.stop_sensor(
-        instigator_origin_id, instigator_selector_id, external_sensors.get(instigator_origin_id)
-    )
-    state = graphene_info.context.instance.get_instigator_state(
+    state = instance.stop_sensor(
         instigator_origin_id,
         instigator_selector_id,
+        external_sensors.get(instigator_origin_id),
     )
     return GrapheneStopSensorMutationResult(state)
 
