@@ -28,6 +28,14 @@ class GraphenePathMetadataEntry(graphene.ObjectType):
         name = "PathMetadataEntry"
 
 
+class GrapheneNotebookMetadataEntry(graphene.ObjectType):
+    path = graphene.NonNull(graphene.String)
+
+    class Meta:
+        interfaces = (GrapheneMetadataEntry,)
+        name = "NotebookMetadataEntry"
+
+
 class GrapheneTableMetadataEntry(graphene.ObjectType):
     table = graphene.NonNull(GrapheneTable)
 
@@ -144,6 +152,7 @@ def types():
         GrapheneMarkdownMetadataEntry,
         GrapheneMetadataItemDefinition,
         GraphenePathMetadataEntry,
+        GrapheneNotebookMetadataEntry,
         GraphenePythonArtifactMetadataEntry,
         GrapheneTextMetadataEntry,
         GrapheneUrlMetadataEntry,
