@@ -1,4 +1,3 @@
-# pylint: disable=missing-graphene-docstring
 import graphene
 
 from ..logs.events import GrapheneDagsterRunEvent
@@ -10,6 +9,7 @@ class GraphenePipelineRunLogsSubscriptionSuccess(graphene.ObjectType):
     run = graphene.NonNull(GrapheneRun)
     messages = non_null_list(GrapheneDagsterRunEvent)
     hasMorePastEvents = graphene.NonNull(graphene.Boolean)
+    cursor = graphene.NonNull(graphene.String)
 
     class Meta:
         name = "PipelineRunLogsSubscriptionSuccess"
